#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-rename-plugin
version:              2.3.0.0
visibility:           public
id:                   hls-rename-plugin-2.3.0.0-664FmOsUfpNoBcBc7GqXo
key:                  hls-rename-plugin-2.3.0.0-664FmOsUfpNoBcBc7GqXo
license:              Apache-2.0
maintainer:           madine.oliver@gmail.com
author:               Oliver Madine
synopsis:             Rename plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  7293eceb9c7e90d4cadf5d5be71af394
exposed:              True
exposed-modules:      Ide.Plugin.Rename
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-rename-plugin-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-rename-plugin-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-rename-plugin-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-rename-plugin
hs-libraries:         HShls-rename-plugin-2.3.0.0-664FmOsUfpNoBcBc7GqXo
depends:
    base-4.18.2.1 containers-0.6.7 extra-1.7.16-92gEBqN3yIpF5We3DBC4D
    ghc-9.6.6 ghc-exactprint-1.7.1.0-GibOHdaOmEHKz6gt8mkn0G
    ghcide-2.3.0.0-hSJ45aUJouJ5cajib6Y2r
    hashable-1.4.7.0-4qZi9v5WFMZ3p1WVFpevAr
    hie-compat-0.3.1.2-37lTPgU0jdr1Ufn5QvEKoZ
    hiedb-0.4.3.0-4waQbA596ldLcqlzFRvkgZ
    hls-plugin-api-2.3.0.0-HIrFfwLMl6A3cQVZo1Nuqf
    hls-refactor-plugin-2.3.0.0-1qLuSrG2gTvGUqbZaUcRik
    lens-5.3.5-60ILU9p4A3b30ZI7X5UwGa
    lsp-2.2.0.0-8keiVbyHMomIz2bmB3Jsqn
    lsp-types-2.0.2.0-11lTtTtX71e7UzNID2IlU5
    mod-0.2.1.0-DQw7P6MEvkv5spLnWrNz3g mtl-2.3.1
    syb-0.7.3-IWvKvWWONKwAx7053zcTAl text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.20.1-4LGdNZVNGNC9SVCFAuU8Mp

haddock-interfaces:
    /usr/share/doc/haskell-hls-rename-plugin/html/hls-rename-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-rename-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

